@@ -134,8 +134,8 @@ def test_member_filter__prot(cpp_class):
     member_names = [m.name for m in cpp_class.members if member_filter(m)]
     assert sorted(member_names) == sorted([
         "ProtectedVariable", "ProtectedEnum", "ProtectedClass", "ProtectedTypedef",
-        "ProtectedStruct", "ProtectedTrash", "MyClass", "operator++", "ProtectedMethod",
-        "ProtectedStaticMethod"
+        "ProtectedStruct", "ProtectedTrash", "MyClass", "MyClass", "MyClass", "operator++",
+        "operator=", "operator=", "ProtectedMethod", "ProtectedStaticMethod", "~MyClass"
     ])
 
 
@@ -159,6 +159,7 @@ def cpp_class_with_inner_classes(cpp_class):
     inner_class_reference = InnerTypeReference(language="cpp")
     inner_class_reference.name = nested_class.name
     inner_class_reference.referred_object = nested_class
+    inner_class_reference.prot = "public"
     cpp_class.inner_classes.append(inner_class_reference)
 
     nested_class = Compound("cpp")
@@ -167,6 +168,7 @@ def cpp_class_with_inner_classes(cpp_class):
     inner_class_reference = InnerTypeReference(language="cpp")
     inner_class_reference.name = nested_class.name
     inner_class_reference.referred_object = nested_class
+    inner_class_reference.prot = "public"
     cpp_class.inner_classes.append(inner_class_reference)
 
     enum_value = EnumValue("cpp")
@@ -189,7 +191,7 @@ def test_inner_class_filter__name(cpp_class_with_inner_classes):
     inner_class_names = [
         m.name for m in cpp_class_with_inner_classes.inner_classes if inner_class_filter(m)
     ]
-    assert sorted(inner_class_names) == sorted(["NestedClass", "NestedStruct"])
+    assert sorted(inner_class_names) == sorted(["NestedStruct"])
 
 
 def test_inner_class_filter__kind(cpp_class_with_inner_classes):
@@ -344,19 +346,21 @@ def test_insertion_filter__compound__no_filters(cpp_class_with_inner_classes):
     ]
     assert sorted(member_names) == sorted([
         "PublicVariable", "PublicEnum", "PublicClass", "PublicTypedef", "PublicStruct",
-        "PublicTrash", "MyClass", "operator++", "PublicMethod", "PublicStaticMethod",
-        "ProtectedVariable", "ProtectedEnum", "ProtectedClass", "ProtectedTypedef",
-        "ProtectedStruct", "ProtectedTrash", "MyClass", "operator++", "ProtectedMethod",
-        "ProtectedStaticMethod", "PrivateVariable", "PrivateEnum", "PrivateClass", "PrivateTypedef",
-        "PrivateStruct", "PrivateTrash", "MyClass", "operator++", "PrivateMethod",
-        "PrivateStaticMethod"
+        "PublicTrash", "MyClass", "MyClass", "MyClass", "MyClass", "MyClass", "MyClass", "MyClass",
+        "operator++", "PublicMethod", "PublicStaticMethod", "ProtectedVariable", "ProtectedEnum",
+        "ProtectedClass", "ProtectedTypedef", "ProtectedStruct", "ProtectedTrash", "MyClass",
+        "operator++", "ProtectedMethod", "ProtectedStaticMethod", "PrivateVariable", "PrivateEnum",
+        "PrivateClass", "PrivateTypedef", "PrivateStruct", "PrivateTrash", "MyClass", "operator++",
+        "PrivateMethod", "PrivateStaticMethod", "operator=", "operator=", "operator=", "operator=",
+        "operator=", "operator=", "~MyClass", "~MyClass", "~MyClass"
     ])
 
     inner_class_names = [
         inner_class.name
         for inner_class in insertion_filter.inner_classes(cpp_class_with_inner_classes)
     ]
-    assert sorted(inner_class_names) == sorted(["NestedClass", "NestedStruct", "AnotherStruct"])
+    assert sorted(inner_class_names) == sorted(
+        ["NestedStruct", "AnotherStruct", "PublicType", "ProtectedType", "PrivateType"])
 
     enum_names = [
         enum_value.name for enum_value in insertion_filter.enum_values(cpp_class_with_inner_classes)
@@ -380,7 +384,8 @@ def test_insertion_filter__compound__filter_members(cpp_class_with_inner_classes
         inner_class.name
         for inner_class in insertion_filter.inner_classes(cpp_class_with_inner_classes)
     ]
-    assert sorted(inner_class_names) == sorted(["NestedClass", "NestedStruct", "AnotherStruct"])
+    assert sorted(inner_class_names) == sorted(
+        ["NestedStruct", "AnotherStruct", "PublicType", "ProtectedType", "PrivateType"])
 
     enum_names = [
         enum_value.name for enum_value in insertion_filter.enum_values(cpp_class_with_inner_classes)
@@ -398,10 +403,12 @@ def test_insertion_filter__compound__filter_inner_classes(cpp_class_with_inner_c
         "PublicVariable", "PublicEnum", "PublicClass", "PublicTypedef", "PublicStruct",
         "PublicTrash", "MyClass", "operator++", "PublicMethod", "PublicStaticMethod",
         "ProtectedVariable", "ProtectedEnum", "ProtectedClass", "ProtectedTypedef",
-        "ProtectedStruct", "ProtectedTrash", "MyClass", "operator++", "ProtectedMethod",
-        "ProtectedStaticMethod", "PrivateVariable", "PrivateEnum", "PrivateClass", "PrivateTypedef",
-        "PrivateStruct", "PrivateTrash", "MyClass", "operator++", "PrivateMethod",
-        "PrivateStaticMethod"
+        "ProtectedStruct", "ProtectedTrash", "MyClass", "MyClass", "MyClass", "MyClass", "MyClass",
+        "MyClass", "MyClass", "operator++", "ProtectedMethod", "ProtectedStaticMethod",
+        "PrivateVariable", "PrivateEnum", "PrivateClass", "PrivateTypedef", "PrivateStruct",
+        "PrivateTrash", "MyClass", "operator++", "PrivateMethod", "PrivateStaticMethod",
+        "operator=", "operator=", "operator=", "operator=", "operator=", "operator=", "~MyClass",
+        "~MyClass", "~MyClass"
     ])
 
     inner_class_names = [
@@ -429,14 +436,17 @@ def test_insertion_filter__compound__filter_enum_values(cpp_class_with_inner_cla
         "ProtectedStruct", "ProtectedTrash", "MyClass", "operator++", "ProtectedMethod",
         "ProtectedStaticMethod", "PrivateVariable", "PrivateEnum", "PrivateClass", "PrivateTypedef",
         "PrivateStruct", "PrivateTrash", "MyClass", "operator++", "PrivateMethod",
-        "PrivateStaticMethod"
+        "PrivateStaticMethod", "MyClass", "MyClass", "MyClass", "MyClass", "MyClass", "MyClass",
+        "operator=", "operator=", "operator=", "operator=", "operator=", "operator=", "~MyClass",
+        "~MyClass", "~MyClass"
     ])
 
     inner_class_names = [
         inner_class.name
         for inner_class in insertion_filter.inner_classes(cpp_class_with_inner_classes)
     ]
-    assert sorted(inner_class_names) == sorted(["NestedClass", "NestedStruct", "AnotherStruct"])
+    assert sorted(inner_class_names) == sorted(
+        ["NestedStruct", "AnotherStruct", "PublicType", "ProtectedType", "PrivateType"])
 
     enum_names = [
         enum_value.name for enum_value in insertion_filter.enum_values(cpp_class_with_inner_classes)
